Application
================================

.. autoclass:: qbittorrentapi.app.AppAPIMixIn
    :members:
    :undoc-members:
    :exclude-members: app, application, app_webapiVersion, app_buildInfo, app_setPreferences, app_defaultSavePath
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.Application
    :members:
    :undoc-members:
    :exclude-members: app, application, webapiVersion, buildInfo, setPreferences, defaultSavePath

.. autoclass:: qbittorrentapi.app.ApplicationPreferencesDictionary
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.BuildInfoDictionary
    :members:
    :undoc-members:
    :show-inheritance:
